@@ -2,10 +2,18 @@
 use strict;
 use warnings;
 
+# Examples:
+# perl eg/gol.pl 5
+# perl eg/gol.pl 5 eg/gol-4x.dat
+# perl eg/gol.pl 12
+# perl eg/gol.pl 12 eg/gol-12-blink.dat
+# perl eg/gol.pl 12 1 # render glider
+
 use Game::Life::Faster ();
 use MIDI::RtMidi::ScorePlayer ();
 use MIDI::Util qw(setup_score set_chan_patch);
 use Music::Scales qw(get_scale_MIDI);
+use Storable qw(retrieve store);
 use Term::ANSIScreen qw(cls);
 
 END {
@@ -20,11 +28,12 @@ END {
 }
 
 my $size = shift || 12;
+my $init = shift || 0; # or some/gol-state.dat file
 
 die "Can't have a size greater than 12 (music notes)\n"
     if $size > 12;
 
-my $scale = 'chromatic';;
+my $scale = 'chromatic';
 if ($size == 7) {
     $scale = 'major';
 }
@@ -37,7 +46,25 @@ elsif ($size == 5) {
 
 my $game = Game::Life::Faster->new($size);
 
-my $matrix = [ map { [ map { int(rand 2) } 1 .. $size ] } 1 .. $size ];
+my $matrix;
+if ($init == 1) {
+    $game->place_points(
+        int $size / 2, int $size / 2,
+        [ [ 1, 1, 1 ],
+          [ 1, 0, 0 ],
+          [ 0, 1, 0 ],
+        ]
+    );
+}
+elsif ($init && -e $init) {
+    $matrix = retrieve($init);
+}
+else {
+    warn "Can't load $init\n" if $init;
+    $matrix = [ map { [ map { int(rand 2) } 1 .. $size ] } 1 .. $size ];
+    store($matrix, 'gol-state.dat');
+}
+
 $game->place_points(0, 0, $matrix);
 
 my @parts = (\&part) x $size;
